@@ -10,7 +10,7 @@ from rich.panel import Panel
 from rich.prompt import Confirm
 from rich.table import Table
 
-from ._checks import pre_run_check
+from ._checks import pre_run_check, thread_check
 from .console import console
 from .extract import extract_all
 from .merge import merge_all
@@ -161,6 +161,8 @@ def print_params(ctx):
         Panel.fit(grid, title=f"{ctx.info_name.capitalize()} Parameters", padding=1)
     )
 
+    thread_check(params["threads"])
+
 
 def save_params(ctx):
     cmd = ctx.info_name
@@ -620,7 +622,6 @@ def merge(
     \n\n\n
     Simple wrapper over `[b cyan]fastp[/]` to combine R1 and R2 from PE fastq files.
     \n\n\n
-    [i]NOTE[/]: fastq files must be gzipped or `[b cyan]pycashier[/]` will exit.
     """
 
     if save_config:
